import React, { useState, useEffect, useRef } from 'react';
import './index.less';
import { Button, Form, message, Modal, Input, Upload } from 'antd';
import { PlusOutlined } from '@ant-design/icons';
// import FacilitysTow from './FacilitysTow';
import { Link, useIntl, connect, Dispatch, history } from 'umi';

function getBase64(file: any) {
  return new Promise((resolve, reject) => {
    const reader = new FileReader();
    reader.readAsDataURL(file);
    reader.onload = () => resolve(reader.result);
    reader.onerror = (error) => reject(error);
  });
}
const module = 'FacilityBookings';

const Facilitys = (props: any) => {
  //传递值
  const { updata, disabled, FacilitysList, dispatch } = props;

  //上传列表
  // const [FacilitysList, setFileList] = useState(FacilitysList);
  //显示隐藏
  const [previewVisible, setpreviewVisible] = useState(false);
  // 名称
  const [previewTitle, setpreviewTitle] = useState('');
  // 图片地址
  const [previewImage, setpreviewImage] = useState('');
  //
  const [idKey, setidKey] = useState(10001);

  // 传递给后台加 key
  const updetaTow = (key: any) => {
    let data = updata;
    data.identification = key;
    return data;
  };

  // 预览
  const handlePreview = async (file: any) => {
    if (!file.url && !file.preview) {
      file.preview = await getBase64(file.originFileObj);
    }
    setpreviewImage(file.url || file.preview);
    setpreviewTitle(file.name);
    setpreviewVisible(true);
  };

  // 点击遮罩回调
  const handleCancel = () => {
    setpreviewVisible(false);
  };

  // 上传属性
  const uploadProps: any = {
    listType: 'picture-card',
    accept: '.jpeg,.png,.jpg',
    action: '/tos/image/upload',
    onChange(info: any) {
      // console.log(info);
      if (info.file.status === 'done') {
        message.success(`${info.file.name} file uploaded successfully`);
        // 拿到key 值  开始存储
        let key = parseInt(info.fileList[0].response.data.identification);
        let list = FacilitysList;
        setidKey(idKey + 1);
        list[key] = {
          id: idKey,
          name: FacilitysList[key].name,
          fileList: info.fileList,
          disabled: false,
        };

        // 存储到mode里面去
        dispatch({ type: module + '/genxin', list });

        console.log(list);
      } else if (info.file.status === 'error') {
        message.error(`${info.file.name} file upload failed.`);
      }
    },
  };

  // 新增动作
  const add = () => {
    setidKey(idKey + 1);
    let list = FacilitysList;
    let adds = {
      id: '-1',
      fileList: [],
      name: '',
      disabled: true,
    };
    // 验证已添加的是否上传完整
    let complete = list.every((item: any) => {
      // return item.fileList.length > 0 && item.name !== '';
      return item.fileList.length > 0;
    });

    if (list.length == 0 || complete) {
      list.push(adds);
      // 存储到mode里面去
      dispatch({ type: module + '/genxin', list });
    } else {
      // 提示每一项都要填写完
      message.error('Please fill out each item ！');
    }

    // 新增的时候把当前的表单输入框清空
    // foEmpty(FacilitysList.length - 1);
  };

  //删除动作
  const deleteImg = (key: any, id: any) => {
    let list = FacilitysList;

    list[key].name = '';
    list.splice(key, 1);
    // 存储到mode里面去
    dispatch({ type: module + '/genxin', list });
  };

  // 删除图片
  const deleteImgs = (key: any, id: any) => {
    let list = FacilitysList;

    list[key].fileList = [];

    // 存储到mode里面去
    dispatch({ type: module + '/genxin', list });
  };

  // 新增按钮
  const uploadButton = (
    <div>
      <PlusOutlined />
      <div className="ant-upload-text">Upload</div>
    </div>
  );

  // 输入框内容
  const monitor = (e: any, index: any) => {
    let list = FacilitysList;
    list[index].name = e.target.value;
    dispatch({ type: module + '/genxin', list });
  };

  return (
    <>
      <Form.Item name="picList" required={false} style={{ marginBottom: 0 }}>
        {FacilitysList
          ? FacilitysList.map((item: any, index: any, key: any) => {
              return (
                <div className={'test'} key={item.id}>
                  <div className={'diybox'} key={item.id}>
                    <Upload
                      {...uploadProps}
                      fileList={
                        FacilitysList[index].fileList.length > 0
                          ? FacilitysList[index].fileList
                          : false
                      }
                      // data={updata}
                      data={updetaTow(index)} // 携带数据
                      disabled={disabled} // 禁止
                      onPreview={handlePreview} // 预览
                      onRemove={() => {
                        deleteImgs(index, item.id);
                      }} //移除
                    >
                      {FacilitysList[index].fileList.length > 0 ? null : uploadButton}
                    </Upload>

                    <div className={'Facility'} key={item.id}>
                      <Form.Item
                        label={`Facility ${index + 1}`}
                        // name={'shebei_' + item.id}
                        rules={[{ required: true, message: 'Please input Facility Name!' }]}
                      >
                        <Input
                          placeholder="Facility Name"
                          disabled={disabled}
                          id={index}
                          onChange={(e: any) => monitor(e, index)}
                          value={FacilitysList[index].name}
                          disabled={FacilitysList[index].disabled || disabled}
                        />
                      </Form.Item>
                      <div className={'over'}>
                        <Button
                          type="link"
                          disabled={disabled}
                          onClick={() => deleteImg(index, item.id)}
                        >
                          Delete
                        </Button>
                      </div>
                    </div>
                  </div>
                </div>
              );
            })
          : ''}
      </Form.Item>
      <Form.Item>
        <Button
          type="dashed"
          onClick={() => add()}
          style={{ width: '100px', height: '100px' }}
          icon={<PlusOutlined />}
          disabled={disabled}
        ></Button>
      </Form.Item>

      {/* 预览表格 */}
      <Modal visible={previewVisible} title={previewTitle} footer={null} onCancel={handleCancel}>
        <img alt="example" style={{ width: '100%' }} src={previewImage} />
      </Modal>
    </>
  );
};

function mapStateToProps(state: any) {
  const { FacilitysList } = state.FacilityBookings;
  return {
    FacilitysList,
  };
}
export default connect(mapStateToProps)(Facilitys);
