import { MenuDataItem, getMenuData, getPageTitle } from '@ant-design/pro-layout';
import { useIntl, ConnectProps, connect } from 'umi';
import React, { useEffect } from 'react';
import { ConnectState } from '@/models/connect';
import logo from '../assets/toslogo.png';
// import {goReserPwd} from '@/models/login';
import styles from './UserLayout.less';

export interface UserLayoutProps extends Partial<ConnectProps> {
  breadcrumbNameMap: {
    [path: string]: MenuDataItem;
  };
  result?: boolean;
}

const UserLayout: React.FC<UserLayoutProps> = (props) => {
  const {
    route = {
      routes: [],
    },
    children,
    location = {
      pathname: '',
    },
    result,
    dispatch,
  } = props;
  const { routes = [] } = route;
  const { formatMessage } = useIntl();
  const { breadcrumb } = getMenuData(routes);
  const title = getPageTitle({
    pathname: location.pathname,
    formatMessage,
    breadcrumb,
    ...props,
  });

  return (
    <div className={styles.container + ' ' + (result ? styles.active : '')}>
      <div className={styles.contain}>
        {!result ? (
          <>
            <img src={logo} alt="" />
            <div className={styles.box2}>Sign In</div>
          </>
        ) : (
          <div className={styles.box1}>
            Change <br /> Password
          </div>
        )}
        {children}
      </div>
    </div>
  );
};

export default connect(({ settings, login }: ConnectState) => {
  return {
    ...settings,
    result: login.result,
  };
})(UserLayout);
