import React, { useEffect } from 'react';
import { Button, Descriptions, Image } from 'antd';
import { EditOutlined, LeftOutlined } from '@ant-design/icons';
import './index.less';
import { connect, history } from 'umi';
import moment from 'moment';

const BugDetail = (props: any) => {
  const { DataSave } = props;

  useEffect(() => {
    if (!DataSave) {
      history.push('/AccountManagement/SystemFeedback');
    }
  }, [DataSave]);

  const goToReturn = () => {
    history.go(-1);
  };

  return (
    <>
      <div className="contop bug">
        <h3 className="capi">
          <EditOutlined />
          &nbsp;System Feedback Details
          <div className="back" onClick={goToReturn}>
            <Button>
              <LeftOutlined />
              Back
            </Button>
          </div>
        </h3>

        <hr></hr>
        <Descriptions column={{ xxl: 1, xl: 1, lg: 1, md: 1, sm: 1, xs: 1 }}>
          <Descriptions.Item label="Mobile phone brands" style={{ paddingBottom: 16 }}>
            {DataSave ? DataSave.phoneBrand : '-'}
          </Descriptions.Item>
          <Descriptions.Item label="Phone model" style={{ paddingBottom: 16 }}>
            {DataSave ? DataSave.deviceModel : '-'}
          </Descriptions.Item>
          <Descriptions.Item label="System version" style={{ paddingBottom: 16 }}>
            {DataSave ? DataSave.osVersion : '-'}
          </Descriptions.Item>
          <Descriptions.Item label="Software version" style={{ paddingBottom: 16 }}>
            {DataSave ? DataSave.appVersion : '-'}
          </Descriptions.Item>
          <Descriptions.Item label="Feedback content" style={{ paddingBottom: 16 }}>
            {DataSave ? DataSave.description : '-'}
          </Descriptions.Item>
          <Descriptions.Item className="diys" label="&nbsp;" style={{ paddingBottom: 16 }}>
            {DataSave
              ? DataSave.imageUrls.map((item: any) => {
                  return <Image width={120} src={item} />;
                })
              : '-'}
          </Descriptions.Item>
          <Descriptions.Item label="Submission time" style={{ paddingBottom: 16 }}>
            {DataSave
              ? moment(DataSave.updateTime.time).format('YYYY-MM-DD hh:mm') +
                // ':00' +
                (parseInt(moment(DataSave.updateTime.time).format('HH')) > 11 ? ' PM' : ' AM')
              : '-'}
          </Descriptions.Item>
        </Descriptions>
      </div>
    </>
  );
};

function BugDetailProps(state: any) {
  const { DataSave } = state.Bug;
  const loading = state.loading.models.Bug || false;
  return {
    DataSave,
    loading,
  };
}

export default connect(BugDetailProps)(BugDetail);
