import React, { useState, useEffect, useRef } from 'react';
import {
  Tabs,
  Spin,
  Input,
  InputNumber,
  Button,
  Form,
  Select,
  message,
  TimePicker,
  Modal,
} from 'antd';
import { connect, history } from 'umi';
import { PoweroffOutlined } from '@ant-design/icons';

const { Option } = Select;
const { RangePicker } = TimePicker;
const { TabPane } = Tabs;
import './css/indexTow.less';
import './css/index.less';

import TitleBack from '@/components/TitleBack/TitleBack';
import Facilitys from '@/components/Facilitys/Facilitys';
import PictureOptionsRow from '@/components/PictureOptions/PictureOptionsRow';

import moment from 'moment';

import { getUrlLast } from '@/utils/string';
import { validateMessages } from '@/utils/params';
import { NewFaci } from '@/utils/tip';

const FacilityTow = (props: any) => {
  const {
    dispatch,
    location,
    DataSaveDetail,
    sourceData,
    DataSave,
    Result,
    load,
    FacilitysList,
  } = props;

  const [PATHNAME, setPATHNAME] = useState('');
  const [facilityDetail, setFacilityDetail] = useState(false); // 全部禁止

  const [ctyName, setCtyName] = useState(null); // 小区名称
  const [fileList, setFileList] = useState([] as any); // 设施总图片列表组
  const [Cycle, setCycle] = useState(null as any); // 周期下拉
  const [Facilityid, setFacilityId] = useState(null as any); // 周期下拉

  const [isModalVisible, setIsModalVisible] = useState(false); // 关闭弹出框

  const formRef = useRef(null as any);
  const [form] = Form.useForm(); // 表单标识
  const module = 'FacilityBookings';

  const RA = (index: any, values: any) => {
    dispatch({ type: 'FacilityBookings/RA', playload: { index: index, body: values } });
  };

  useEffect(() => {
    if (location.pathname.indexOf('FacilityDetail') > -1) {
      setPATHNAME('Facility Detail');
    } else {
      setPATHNAME('Edit Facility');
    }
  }, []);

  // 传递来的小区和设施
  useEffect(() => {
    if (DataSave) {
      if (DataSave.type == 0) {
        setFacilityDetail(true);
      }
      setCtyName(DataSave.community);
      setFacilityId(DataSave.facilities[0].id);
      beg(DataSave.facilities[0].id);

      DataSave.facilities.sort((n1: any, n2: any) => {
        return n1.id - n2.id;
      });
    } else {
      history.go(-1);
    }
  }, [DataSave]);

  // 点击设施获取到的设施列表
  useEffect(() => {
    if (DataSaveDetail !== null) {
      let { categories, facilities } = DataSaveDetail;

      // 设施A、设施B小图
      let list: any = categories
        ? categories.map((item: any, index: any) => {
            let sam = {
              id: index,
              name: item.categoriesName,
              fileList: [
                {
                  uid: item.id,
                  name: item.categoriesImageName,
                  status: 'done',
                  url: item.categoriesImageUrl,
                },
              ],
            };
            // 设施图片列表默认值
            form.setFieldsValue({
              ['shebei_' + index]: item.categoriesName,
            });
            return sam;
          })
        : [];
      dispatch({ type: module + '/genxin', list });

      // 设施总图片
      let fileListImg: any = [];

      if (facilities) {
        facilities.facilitiesImageList.map((item: any, index: any) => {
          let sam = {
            uid: index,
            name: item.facilitiesImageName,
            status: 'done',
            url: item.facilitiesImageUrl,
          };
          fileListImg.push(sam);
        });

        // 设置表单默认值
        formRef.current.setFieldsValue(facilities);
        // 周期
        setCycle(facilities.periodType + '');
        // 时间
        let time = facilities.reservationQuantumTime.split(',');
        formRef.current.setFieldsValue({
          Time: [moment(time[0], 'HH:mm'), moment(time[1], 'HH:mm')],
        });
      }

      setFileList([...fileListImg]);
    }
  }, [DataSaveDetail]);

  // tab 切换
  const onTabClicks = (id: String) => {
    // 清空设施图片
    let list: any = [];
    dispatch({ type: 'FacilityBookings/genxin', list });
    form.resetFields(); // 清空所有表单值
    setFacilityId(id);
    beg(id);
  };
  // 判断数组是否有重复项
  function isRepeat(arr: any) {
    let hash = {};
    for (let i in arr) {
      if (hash[arr[i]]) {
        return true;
      }
      hash[arr[i]] = true;
    }
    return false;
  }

  // 提交
  const onFinish = (values: any) => {
    // console.log(FacilitysList);
    // 先判断是否填写完整
    for (let j in FacilitysList) {
      if (FacilitysList[j].fileList.length == 0) {
        message.error('Please upload classified pictures of facilities!');
        return false;
      }
    }

    // 提取设施icon图和名称出来;
    let imgs: any = []; // 小设施图片  -- 用作提交
    let name = []; // 小设施名称  -- 用作判断重名

    for (let i in FacilitysList) {
      // 设施名称不能为空
      if (FacilitysList[i].name == '') {
        message.error('Facility name cannot be empty!');
        return false;
      }

      name.push(FacilitysList[i].name);
      imgs[
        i
      ] = `${FacilitysList[i].name}&${FacilitysList[i].fileList[0].name}&${FacilitysList[i].fileList[0].uid}`;
    }

    // 单个的话也转化为数组
    if (typeof values.categoriesDetailsImageName == 'string') {
      values.categoriesDetailsImageName = values.categoriesDetailsImageName.split(',');
    }

    // 如果小设施有重名
    if (isRepeat(name)) {
      message.error('Facility name cannot be repeated!');
    } else if (imgs.length == 0) {
      // 图片设施判断
      message.error('Please Upload At Least One Facility!');
    } else if (
      // 提前预订时间大于 取消时间
      values.canReservationDay < values.cancelReservationDay ||
      values.canReservationDay < values.nomarginCancelReservationDay
    ) {
      message.error('Reservation should be greater than cancellation time!');
    } else {
      let categoriesName: any = imgs; // 设施图片
      values.categoriesName = categoriesName; // 设施内容
      values.reservationQuantumTime = [
        moment(values.Time[0]).format('HH:mm'),
        moment(values.Time[1]).format('HH:mm'),
      ]; // 开放时间段
      values.categoriesOpenTime = `${moment(values.Time[0]).format('HH:mm')}-${moment(
        values.Time[1],
      ).format('HH:mm')}`; // 预约时间段  二开需要
      values.communityManagerFee = values.communityManagerFee ? values.communityManagerFee : '0.00'; // 价格押金没有为0
      values.communityMargin = values.communityMargin ? values.communityMargin : '0.00'; // 价格押金没有为0
      values.communityName = DataSave.community;
      values.periodType = Cycle;
      values.id = Facilityid;

      delete values.startTime;
      delete values.endTime;
      delete values.picList;
      delete values.Time;
      RA(17, values);
    }
  };

  // 发起请求
  const beg = (id: String) => {
    RA(60, { facilitiesId: id });
  };

  // 监听输入框值全填了就搜索
  const keyup = (keyname: any, e: any) => {
    e.target.value = e.target.value.replace(/[^\d^\.]+/g, '');
    var tmp = {};
    tmp[keyname] = e.target.value;
    formRef.current.setFieldsValue(tmp);
  };

  //选择周期
  function handleChange(value: any) {
    setCycle(value);
  }

  //时间
  const onChanges = (value: any, b: any) => {
    // console.log(value);
    // console.log(b);
    // 修改后的时间
    formRef.current.setFieldsValue({
      Time: [moment(b[0], 'HH:mm'), moment(b[1], 'HH:mm')],
    });
  };

  // 打开关闭框
  const showModal = () => {
    setIsModalVisible(true);
  };

  // 确认删除
  const handleOk = () => {
    // setIsModalVisible(false);
    message.info('In function development');
  };

  // 关闭关闭框
  const handleCancel = () => {
    setIsModalVisible(false);
  };

  // 关闭按钮
  const operations = (
    <Button type="primary" danger onClick={showModal}>
      <PoweroffOutlined />
      Close The Selected Facility
    </Button>
  );

  return (
    <>
      {DataSave ? (
        <div style={{ padding: 16 }}>
          {/* 头部组件v1.2 */}
          <TitleBack title={PATHNAME} url={getUrlLast(location.pathname) + '?Facility=true'} />

          {/* 设施切换  */}

          <div className={'FacilityName'}>
            <label>Community :</label> {DataSave ? DataSave.community : ''}
          </div>

          <Tabs
            defaultActiveKey="0"
            tabPosition="top"
            onTabClick={(key) => onTabClicks(key)}
            tabBarExtraContent={facilityDetail ? operations : ''}
          >
            {DataSave
              ? DataSave.facilities.map((i: any) => (
                  <TabPane tab={`${i.name}`} key={i.id}></TabPane>
                ))
              : ''}
          </Tabs>

          {/* 设施内容 */}
          <Spin spinning={load}>
            <div className={'base basediy'}>
              <Form
                ref={formRef}
                form={form}
                name="basic"
                onFinish={onFinish}
                validateMessages={validateMessages}
                labelAlign="right"
              >
                {/* 设施名称 以及费用 */}
                <Input.Group>
                  <Form.Item label="Facility Classification" name="facilityName" rules={NewFaci[1]}>
                    <Input
                      placeholder="Facility Classification"
                      disabled={facilityDetail}
                      maxLength={30}
                    />
                  </Form.Item>
                  <span className="divIconMoney">Fee($):</span>
                  <Form.Item label="" name="communityManagerFee">
                    <InputNumber
                      prefix="$"
                      placeholder="00.00"
                      disabled={facilityDetail}
                      min={0}
                      max={999}
                      step={0.01}
                      style={{ width: '120px' }}
                    />
                  </Form.Item>
                  <span className="divIconMoney">Deposit:</span>
                  <Form.Item label="" name="communityMargin">
                    <InputNumber
                      prefix="$"
                      placeholder="00.00"
                      disabled={facilityDetail}
                      min={0}
                      max={999}
                      step={0.01}
                      style={{ width: '120px' }}
                    />
                  </Form.Item>
                </Input.Group>

                <hr></hr>

                {/* 设施品类上传 */}
                <Form.Item
                  label="Facilities"
                  className="flex required"
                  style={{ marginBottom: 0, minHeight: 134 }}
                >
                  <Facilitys
                    disabled={facilityDetail}
                    updata={{
                      // userToken: token,
                      imageType: 'categoriesImageName',
                      extends: ctyName,
                    }}
                  ></Facilitys>
                </Form.Item>

                {/* 设施详情上传 */}
                <Form.Item
                  name="categoriesDetailsImageName"
                  label="Facility Pictures"
                  rules={NewFaci[4]}
                >
                  <PictureOptionsRow
                    over={facilityDetail}
                    data={{
                      // userToken: token,
                      imageType: 'categoriesDetailsImageName',
                      extends: ctyName,
                    }}
                    limitNums={99}
                    imgs={fileList}
                  />
                </Form.Item>

                {/* 时间 */}
                <Form.Item label="Opening Hours" className="required">
                  <Form.Item name="Time" noStyle>
                    <RangePicker
                      minuteStep={60}
                      format="HH:mm"
                      onChange={(time: any, timeString: any) => {
                        onChanges(time, timeString);
                      }}
                      allowClear={false}
                      disabled={facilityDetail}
                    />
                  </Form.Item>
                </Form.Item>

                <hr></hr>

                {/* ------------- */}
                <p className="diyp">Booking Rules : </p>

                {/* 预约设置 */}
                <Input.Group>
                  <Form.Item
                    name="cancelReservationDay"
                    label="Early Cancellation"
                    rules={NewFaci[5]}
                  >
                    <Input
                      onKeyUp={keyup.bind(this, 'cancelReservationDay')}
                      disabled={facilityDetail}
                      // prefix="Advance"
                      suffix="Day(s) In Advance"
                      style={{ width: 160, textAlign: 'center' }}
                      placeholder="0"
                      maxLength={2}
                    />
                  </Form.Item>
                  <Form.Item
                    label="No Deposit To Cancel Reservation"
                    name="nomarginCancelReservationDay"
                    rules={NewFaci[6]}
                  >
                    <Input
                      onKeyUp={keyup.bind(this, 'nomarginCancelReservationDay')}
                      disabled={facilityDetail}
                      // prefix="Advance"
                      suffix="Day(s) In Advance"
                      style={{ width: 160, textAlign: 'center' }}
                      placeholder="0"
                      maxLength={2}
                    />
                  </Form.Item>
                  <Form.Item label="Booking" name="canReservationDay" rules={NewFaci[7]}>
                    <Input
                      onKeyUp={keyup.bind(this, 'canReservationDay')}
                      placeholder="0"
                      style={{ width: 160, textAlign: 'center' }}
                      disabled={facilityDetail}
                      // prefix="Advance"
                      suffix="Day(s) In Advance"
                      maxLength={2}
                    />
                  </Form.Item>
                </Input.Group>

                {/* 设置次数 */}
                <Input.Group>
                  <Form.Item label="Booking Quotas" rules={NewFaci[8]}>
                    <Select
                      placeholder="Cycle"
                      allowClear
                      style={{ width: 120 }}
                      disabled={facilityDetail}
                      value={Cycle}
                      onChange={handleChange}
                    >
                      <Option value="1">Week</Option>
                      <Option value="2">Month</Option>
                      <Option value="3">Year</Option>
                    </Select>
                  </Form.Item>
                  <Form.Item name="canReservationNum" rules={NewFaci[9]}>
                    <Input
                      onKeyUp={keyup.bind(this, 'canReservationNum')}
                      placeholder="Second"
                      style={{ width: 120 }}
                      disabled={facilityDetail}
                      defaultValue={0}
                      suffix="Time(s)"
                    />
                  </Form.Item>
                </Input.Group>

                <hr></hr>

                <>
                  <Button type="primary" htmlType="submit" loading={load} disabled={facilityDetail}>
                    Submit
                  </Button>
                </>
              </Form>
            </div>
          </Spin>

          <Modal
            title="Close Facility"
            visible={isModalVisible}
            onOk={handleOk}
            okText={'Confirm'}
            cancelText={'Cancel'}
            onCancel={handleCancel}
            centered
            confirmLoading={load}
          >
            <p>
              Closing of facilities :{' '}
              <span style={{ color: '#f00' }}>
                {DataSaveDetail &&
                DataSaveDetail.facilities &&
                DataSaveDetail.facilities.facilityName
                  ? DataSaveDetail.facilities.facilityName
                  : ''}{' '}
              </span>
              ?
            </p>
          </Modal>
        </div>
      ) : (
        ''
      )}
    </>
  );
};

function mapStateToProps(state: any) {
  const { sourceData, DataSave, DataSaveDetail, Result, FacilitysList } = state.FacilityBookings;
  const { token } = state.login;
  const load = state.loading.models.FacilityBookings || false;
  return {
    DataSave,
    DataSaveDetail,
    sourceData,
    token,
    Result,
    load,
    FacilitysList,
  };
}
export default connect(mapStateToProps)(FacilityTow);
