import { ArrowLeftOutlined } from '@ant-design/icons';
import { message, Form, Button, Checkbox, Input } from 'antd';
import React, { useState, useEffect, useCallback } from 'react';
import { connect, Dispatch, history } from 'umi';
import { StateType } from '@/models/login';
import { LoginParamsType, getCaptcha, ValidateCaptcha } from '@/services/login';
import { ConnectState } from '@/models/connect';

import { ExclamationCircleFilled } from '@ant-design/icons';

import styles from './style.less';
import { getCookie } from '@/utils/method';

interface LoginProps {
  dispatch: Dispatch;
  userLogin: StateType;
  submitting?: boolean;
}

const Login: React.FC<LoginProps> = (props) => {
  const { userLogin = {}, submitting, dispatch } = props;
  const { status, type: loginType, resultLogin } = userLogin;

  const [userName, setUsername] = useState('');
  const [forgetflag, setForgetFlag] = useState(false);

  const [count, setCount] = useState<number>(60);
  const [timing, setTiming] = useState(false);

  const [remenber, setRemenber] = useState(false);

  const [form] = Form.useForm();

  // 判断本地是否存储的有账号密码
  useEffect(() => {
    if (location.pathname === '/user/login') {
      const name = getCookie('remenberUserName');
      const Pwd = getCookie('remenberPwd');
      console.log(name, Pwd);
      if (Pwd && name) {
        setRemenber(true);
        const values = {
          userName: name,
          password: Pwd,
        };
        form.setFieldsValue(values);
      }
    }
  }, []);

  // 提交按钮
  const handleSubmit = async (values: LoginParamsType) => {
    if (forgetflag) {
      if (!values.userName || !values.code) {
        message.error('The mailbox or verification code cannot be empty!!!');
        return;
      }
      const res = await ValidateCaptcha({ account: values.userName, code: values.code });

      if (res.error_code === '0000') {
        dispatch({
          type: 'login/goResetPwd',
          payload: userName,
        });
      } else {
        message.error('MemberCode!');
        dispatch({
          type: 'login/setResult',
          payload: {
            resultLogin: true,
          },
        });
      }
    } else {
      if (values.userName && values.password) {
        dispatch({
          type: 'login/login',
          payload: { values, remenber },
        });
      } else {
        message.error('The username or password cannot be empty!');
      }
    }
  };

  // 用户名
  const usernameHandle = (e: any) => {
    setUsername(e.target.value);
  };

  // 登录
  const returnHandle = () => {
    history.push('/user/login');
  };

  // 忘记密码
  const gotoForgetHandle = () => {
    history.push('/user/forget');
  };

  // 发送验证码
  const handleSend = () => {
    if (timing) return;
    if (
      userName !== '' &&
      /^[a-z0-9]+([._\\-]*[a-z0-9])*@([a-z0-9]+[-a-z0-9]*[a-z0-9]+.){1,63}[a-z0-9]+$/.test(userName)
    ) {
      console.log('邮箱正确!');
      onGetCaptcha(userName);
    } else {
      message.warning('Please enter the correct email address!');
    }
  };

  // 保存密码
  const onRemenberChange = (e: Readonly<{ target: { checked: boolean } }>) => {
    setRemenber(e.target.checked);
  };

  // 获取验证码
  const onGetCaptcha = useCallback(async (email: string) => {
    // getFakeCaptcha
    // getCaptcha
    setTiming(true);
    const result = await getCaptcha({ account: email });
    console.log(result);
    if (result.error_code === '0000') {
      message.success('Has Been Sent!');
    } else {
      message.error(result.error_msg);
    }
  }, []);

  // 监听路由
  useEffect(() => {
    if (location.pathname == '/user/forget') {
      setForgetFlag(true);
    } else {
      setForgetFlag(false);
    }

    // 路由发生变化 清楚错误提示
    dispatch({
      type: 'login/setResult',
      payload: {},
    });
  }, [location.pathname]);

  // 发送验证码的秒数
  useEffect(() => {
    let interval: number = 0;
    if (timing) {
      interval = window.setInterval(() => {
        setCount((preSecond) => {
          if (preSecond <= 1) {
            setTiming(false);
            clearInterval(interval);
            // 重置秒数
            return 60;
          }
          return preSecond - 1;
        });
      }, 1000);
    }
    return () => clearInterval(interval);
  }, [timing]);

  return (
    <div>
      {forgetflag ? (
        <div
          style={{ position: 'absolute', top: 20, left: 30, cursor: 'pointer' }}
          onClick={returnHandle}
        >
          <ArrowLeftOutlined style={{ fontSize: '28px' }} />
        </div>
      ) : (
        <div />
      )}
      <Form onFinish={handleSubmit} form={form}>
        <div className={styles.box1}>
          {forgetflag ? 'Please enter email address' : 'Account Numbers'}
        </div>
        <Form.Item name="userName" initialValue={userName || ''}>
          <input className={styles.input} onChange={usernameHandle} />
        </Form.Item>
        <div className={styles.box1}>
          {forgetflag ? 'Please enter a verification code' : 'Password'}
        </div>
        {forgetflag ? (
          <div className={styles.box2}>
            <Form.Item name="code" initialValue="">
              <input className={styles.input5} />
            </Form.Item>
            <div
              className={styles.button2 + ' ' + (timing ? '' : userName && styles.active)}
              style={{ float: 'right' }}
              onClick={handleSend}
            >
              {timing ? `${count} 秒` : 'Send'}
            </div>
          </div>
        ) : (
          <div>
            <Form.Item name="password" initialValue="">
              <Input.Password className={styles.input2} />
            </Form.Item>
            <div>
              <div style={{ display: 'flex', justifyContent: 'space-between' }}>
                <Checkbox
                  checked={remenber}
                  className={styles.checkbox}
                  onChange={onRemenberChange}
                >
                  Remenber me
                </Checkbox>

                <div className={styles.input3} onClick={gotoForgetHandle}>
                  Forget Password
                </div>
              </div>
            </div>
          </div>
        )}
        <div className={styles.input4}>
          {resultLogin && (
            <div>
              <ExclamationCircleFilled style={{ fontSize: '20px', marginRight: '5px' }} />
              {location.pathname === '/user/forget' ? 'MemberCode' : 'Wrong account or password'}
            </div>
          )}
        </div>
        <Form.Item>
          <Button
            style={{
              width: 330,
              height: 50,
              fontSize: 20,
              backgroundColor: '#B4D87CFF',
              borderColor: '#B4D87CFF',
              marginTop: '40px',
              borderRadius: '16px',
            }}
            type="primary"
            htmlType="submit"
          >
            {forgetflag ? 'Next' : 'Log In'}
          </Button>
        </Form.Item>
      </Form>
    </div>
  );
};

export default connect(({ login, loading }: ConnectState) => {
  return {
    userLogin: login,
    submitting: loading.effects['login/login'],
  };
})(Login);
